
aftercovid: modelling, simulation, statistics around COVID
==========================================================

.. image:: https://circleci.com/gh/sdpython/aftercovid/tree/master.svg?style=svg
    :target: https://circleci.com/gh/sdpython/aftercovid/tree/master

.. image:: https://travis-ci.org/sdpython/aftercovid.svg?branch=master
    :target: https://travis-ci.org/sdpython/aftercovid
    :alt: Build status

.. image:: https://ci.appveyor.com/api/projects/status/ffne8nhh96jdqo4p?svg=true
    :target: https://ci.appveyor.com/project/sdpython/aftercovid
    :alt: Build Status Windows

.. image:: https://codecov.io/gh/sdpython/aftercovid/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/sdpython/aftercovid

.. image:: https://badge.fury.io/py/aftercovid.svg
    :target: http://badge.fury.io/py/aftercovid

.. image:: http://img.shields.io/github/issues/sdpython/aftercovid.png
    :alt: GitHub Issues
    :target: https://github.com/sdpython/aftercovid/issues

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: http://opensource.org/licenses/MIT

Modélisation, statistiques, modelling, statistics à propos about :epkg:`COVID`.

.. toctree::
    :maxdepth: 1

    tutorial
    readings
    api
    auto_examples/index
    dev

Sources available on
`github/aftercovid <https://github.com/sdpython/aftercovid>`_.

*Indices and tables*

* :ref:`genindex`
* `Code coverage <coverage.html>`_
